@@ -4,7 +4,6 @@ Basic data manipulation with SQL.
 *(The current release includes* `PostgreSQL <https://www.postgresql.org/>`_ *only.)*
 """
 
-import copy
 import csv
 import gc
 import getpass
@@ -15,8 +14,7 @@ import tempfile
 import pandas as pd
 import pandas.io.parsers
 import sqlalchemy
-import sqlalchemy.engine.reflection
-import sqlalchemy.engine.url
+import sqlalchemy.engine
 
 from .ops import confirmed
 
@@ -72,10 +70,10 @@ class PostgreSQL:
     :type confirm_new_db: bool
     :param verbose: whether to print relevant information in console as the function runs,
         defaults to ``True``
-    :type verbose: bool
+    :type verbose: bool or int
 
     :ivar dict database_info: basic information about the server/database being connected
-    :ivar sqlalchemy.engine.url.URL url: PostgreSQL database URL;
+    :ivar sqlalchemy.engine.URL url: PostgreSQL database URL;
         see also [`SQL-P-SP-1`_]
     :ivar type dialect: system that SQLAlchemy uses to communicate with PostgreSQL;
         see also [`SQL-P-SP-2`_]
@@ -129,8 +127,7 @@ class PostgreSQL:
         ...                  password=None, database_name='testdb', **kwargs):
         ...
         ...         super().__init__(host=host, port=port, username=username,
-        ...                          password=password, database_name=database_name,
-        ...                          **kwargs)
+        ...                          password=password, database_name=database_name, **kwargs)
 
         >>> example_proxy_obj = ExampleProxyObj()
         Password (postgres@localhost:5432): ***
@@ -163,7 +160,7 @@ class PostgreSQL:
                               'database': database_name_}
 
         # The typical form of the URL: backend+driver://username:password@host:port/database
-        self.url = sqlalchemy.engine.url.URL.create(**self.database_info)
+        self.url = sqlalchemy.engine.URL.create(**self.database_info)
 
         self.dialect = self.url.get_dialect()
         self.backend = self.url.get_backend_name()
@@ -174,7 +171,7 @@ class PostgreSQL:
         if self.database_name != 'postgres':
             db_info = self.database_info.copy()
             db_info['database'] = 'postgres'
-            url = sqlalchemy.engine.url.URL.create(**db_info)
+            url = sqlalchemy.engine.URL.create(**db_info)
             self.engine = sqlalchemy.create_engine(url, isolation_level='AUTOCOMMIT')
             db_exists = self.engine.execute(
                 "SELECT EXISTS("
@@ -189,7 +186,8 @@ class PostgreSQL:
             if confirmed("The database \"{}\" does not exist. "
                          "Proceed by creating it?".format(self.database_name),
                          confirmation_required=confirm_new_db):
-                print("Connecting {}".format(self.address), end=" ... ") if verbose else ""
+                if verbose:
+                    print("Connecting {}".format(self.address), end=" ... ")
 
                 self.engine.execute('CREATE DATABASE "{}";'.format(self.database_name))
                 self.engine.dispose()
@@ -200,7 +198,9 @@ class PostgreSQL:
 
         try:  # Create a SQLAlchemy connectable
             self.engine = sqlalchemy.create_engine(self.url, isolation_level='AUTOCOMMIT')
-            print("Successfully.") if verbose else ""
+
+            if verbose:
+                print("Successfully.")
 
         except Exception as e:
             print("Failed. {}.".format(e))
@@ -225,6 +225,7 @@ class PostgreSQL:
             >>> testdb.database_exists('testdb')
             True
 
+            >>> # Delete the database "testdb"
             >>> testdb.drop_database(verbose=True)
             To drop the database "testdb" from postgres:***@localhost:5432
             ? [No]|Yes: yes
@@ -251,7 +252,7 @@ class PostgreSQL:
         :type database_name: str
         :param verbose: whether to print relevant information in console as the function runs,
             defaults to ``False``
-        :type verbose: bool
+        :type verbose: bool or int
 
         **Example**::
 
@@ -267,6 +268,7 @@ class PostgreSQL:
             >>> print(testdb.database_name)
             testdb1
 
+            >>> # Delete the database "testdb"
             >>> testdb.drop_database(verbose=True)
             To drop the database "testdb1" from postgres:***@localhost:5432
             ? [No]|Yes: yes
@@ -280,10 +282,12 @@ class PostgreSQL:
             self.disconnect_database()
             self.engine.execute('CREATE DATABASE "{}";'.format(database_name))
 
-            print("Done.") if verbose else ""
+            if verbose:
+                print("Done.")
 
         else:
-            print("The database already exists.") if verbose else ""
+            if verbose:
+                print("The database already exists.")
 
         self.connect_database(database_name)
 
@@ -296,7 +300,7 @@ class PostgreSQL:
         :type database_name: str or None
         :param verbose: whether to print relevant information in console as the function runs, 
             defaults to ``False``
-        :type verbose: bool
+        :type verbose: bool or int
 
         **Example**::
 
@@ -322,11 +326,12 @@ class PostgreSQL:
 
             self.address = "{}:***@{}:{}/{}".format(self.user, self.host, self.port, self.database_name)
 
-            print("Connecting {}".format(self.address), end=" ... ") if verbose else ""
+            if verbose:
+                print("Connecting {}".format(self.address), end=" ... ")
 
             try:
                 self.database_info['database'] = self.database_name
-                self.url = sqlalchemy.engine.url.URL(**self.database_info)
+                self.url = sqlalchemy.engine.URL.create(**self.database_info)
 
                 if not self.database_exists(self.database_name):
                     self.create_database(database_name=self.database_name)
@@ -334,7 +339,8 @@ class PostgreSQL:
                 self.engine = sqlalchemy.create_engine(self.url, isolation_level='AUTOCOMMIT')
                 # self.connection = self.engine.raw_connection()
 
-                print("Successfully.") if verbose else ""
+                if verbose:
+                    print("Successfully.")
 
             except Exception as e:
                 print("Failed. {}.".format(e))
@@ -380,7 +386,7 @@ class PostgreSQL:
         :type database_name: str or None
         :param verbose: whether to print relevant information in console as the function runs, 
             defaults to ``False``
-        :type verbose: bool
+        :type verbose: bool or int
 
         **Example**::
 
@@ -413,7 +419,8 @@ class PostgreSQL:
                 'FROM pg_stat_activity '
                 'WHERE datname = \'{}\' AND pid <> pg_backend_pid();'.format(db_name))
 
-            print("Done.") if verbose else ""
+            if verbose:
+                print("Done.")
 
         except Exception as e:
             print("Failed. {}".format(e))
@@ -456,7 +463,7 @@ class PostgreSQL:
         :type confirmation_required: bool
         :param verbose: whether to print relevant information in console as the function runs, 
             defaults to ``False``
-        :type verbose: bool
+        :type verbose: bool or int
 
         **Example**::
 
@@ -466,6 +473,7 @@ class PostgreSQL:
             Password (postgres@localhost:5432): ***
             Connecting postgres:***@localhost:5432/testdb ... Successfully.
 
+            >>> # Delete the database "testdb"
             >>> testdb.drop_database(verbose=True)
             To drop the database "testdb" from postgres:***@localhost:5432
             ? [No]|Yes: yes
@@ -488,22 +496,23 @@ class PostgreSQL:
                 print("The database \"{}\" does not exist.".format(db_name))
 
         else:
-            if confirmed("To drop the database \"{}\" from {}\n?".format(
-                    db_name, self.address.replace(f"/{db_name}", "")),
-                    confirmation_required=confirmation_required):
+            address_ = self.address.replace(f"/{db_name}", "")
+            if confirmed("To drop the database \"{}\" from {}\n?".format(db_name, address_),
+                         confirmation_required=confirmation_required):
                 self.disconnect_database(db_name)
 
                 if verbose:
                     if confirmation_required:
                         log_msg = "Dropping \"{}\"".format(db_name)
                     else:
-                        log_msg = "Dropping the database \"{}\"".format(db_name)
+                        log_msg = "Dropping the database \"{}\" from {}".format(db_name, address_)
                     print(log_msg, end=" ... ")
 
                 try:
                     self.engine.execute('DROP DATABASE "{}"'.format(db_name))
 
-                    print("Done.") if verbose else ""
+                    if verbose:
+                        print("Done.")
 
                 except Exception as e:
                     print("Failed. {}".format(e))
@@ -547,7 +556,7 @@ class PostgreSQL:
         :type schema_name: str
         :param verbose: whether to print relevant information in console as the function runs, 
             defaults to ``False``
-        :type verbose: bool
+        :type verbose: bool or int
 
         **Example**::
 
@@ -569,6 +578,12 @@ class PostgreSQL:
             To drop the schema "test_schema" from postgres:***@localhost:5432/testdb
             ? [No]|Yes: yes
             Dropping "test_schema" ... Done.
+
+            >>> # Delete the database "testdb"
+            >>> testdb.drop_database(verbose=True)
+            To drop the database "testdb" from postgres:***@localhost:5432
+            ? [No]|Yes: yes
+            Dropping "testdb" ... Done.
         """
 
         if not self.schema_exists(schema_name=schema_name):
@@ -579,7 +594,8 @@ class PostgreSQL:
             try:
                 self.engine.execute('CREATE SCHEMA IF NOT EXISTS "{}";'.format(schema_name))
 
-                print("Done.") if verbose else ""
+                if verbose:
+                    print("Done.")
 
             except Exception as e:
                 print("Failed. {}".format(e))
@@ -587,13 +603,13 @@ class PostgreSQL:
         else:
             print("The schema \"{}\" already exists.".format(schema_name))
 
-    def msg_for_multi_schemas(self, item_names, desc='schema'):
+    def _msg_for_multi_items(self, item_names, desc):
         """
-        Formulate printing message for multiple schemas.
+        Formulate printing message for multiple items.
 
         :param item_names: name of one table/schema, or names of several tables/schemas
-        :type item_names: str or collections.abc.Iterable
-        :param desc: for additional description, defaults to ``'schema'``
+        :type item_names: str or typing.Iterable
+        :param desc: for additional description
         :type desc: str
         :return: printing message
         :rtype: tuple
@@ -607,55 +623,58 @@ class PostgreSQL:
             Connecting postgres:***@localhost:5432/testdb ... Successfully.
 
             >>> schema_name = 'points'
-            >>> schemas, msg = testdb.msg_for_multi_schemas(schema_name, desc='schema')
+            >>> schemas, prt_pl, prt_name = testdb._msg_for_multi_items(schema_name, desc='schema')
 
             >>> print(schemas)
             ['points']
-            >>> print(msg)
+            >>> print(prt_pl, prt_name)
             schema "points"
 
             >>> schema_names = ['points', 'lines', 'polygons']
-            >>> schemas, msg = testdb.msg_for_multi_schemas(schema_names, desc='schema')
+            >>> schemas, prt_pl, prt_name = testdb._msg_for_multi_items(schema_names, desc='schema')
 
             >>> print(schemas)
             ['points', 'lines', 'polygons']
-            >>> print(msg)
-            schemas:
-                "points",
-                "lines" and
+            >>> print(prt_pl, prt_name)
+            schemas
+                "points"
+                "lines"
                 "polygons"
 
         :meta private:
         """
 
         if item_names is None:
-            inspector = sqlalchemy.engine.reflection.Inspector.from_engine(self.engine)
-            items = [x for x in inspector.get_schema_names()
-                     if x != 'public' and x != 'information_schema']
+            item_names_ = [
+                x for x in sqlalchemy.inspect(self.engine).get_schema_names()
+                if x != 'public' and x != 'information_schema']
         else:
-            items = [item_names] if isinstance(item_names, str) else copy.copy(item_names)
+            item_names_ = [item_names] if isinstance(item_names, str) else item_names
 
-        if len(items) == 1:
-            print_plural = "{} ".format(desc)
-            print_schema = "\"{}\"".format(items[0])
+        if len(item_names_) == 1:
+            print_plural = "{}".format(desc)
+            try:
+                print_items = "\"{}\"".format(item_names_[0])
+            except TypeError:
+                print_items = "\"{}\"".format(list(item_names_)[0])
         else:
-            print_plural = "{}s: ".format(desc)
-            print_schema = ("\n\t\"{}\"" * len(items)).format(*items)
+            print_plural = "{}s".format(desc)
+            print_items = ("\n\t\"{}\"" * len(item_names_)).format(*item_names_)
 
-        return items, print_plural + print_schema
+        return item_names_, print_plural, print_items
 
     def drop_schema(self, schema_names, confirmation_required=True, verbose=False):
         """
         Drop a schema in the database being connected.
 
         :param schema_names: name of one schema, or names of multiple schemas
-        :type schema_names: str or collections.abc.Iterable
+        :type schema_names: str or typing.Iterable
         :param confirmation_required: whether to prompt a message for confirmation to proceed,
             defaults to ``True``
         :type confirmation_required: bool
         :param verbose: whether to print relevant information in console as the function runs, 
             defaults to ``False``
-        :type verbose: bool
+        :type verbose: bool or int
 
         **Example**::
 
@@ -668,61 +687,75 @@ class PostgreSQL:
             >>> new_schema_names = ['points', 'lines', 'polygons']
             >>> new_schema_names_ = ['test_schema']
 
-            >>> for new_schema in new_schema_names: testdb.create_schema(new_schema, verbose=True)
+            >>> for new_schema in new_schema_names:
+            ...     testdb.create_schema(new_schema, verbose=True)
             Creating a schema: "points" ... Done.
             Creating a schema: "lines" ... Done.
             Creating a schema: "polygons" ... Done.
 
             >>> testdb.drop_schema(new_schema_names + new_schema_names_, verbose=True)
-            To drop the following schemas:
+            To drop the following schemas from postgres:***@localhost:5432/testdb:
                 "points"
                 "lines"
                 "polygons"
                 "test_schema"
-             from postgres:***@localhost:5432/testdb
             ? [No]|Yes: yes
             Dropping ...
                 "points" ... Done.
                 "lines" ... Done.
                 "polygons" ... Done.
-                "test_schema" does not exist.
+                "test_schema" (does not exist.)
+
+            >>> # Delete the database "testdb"
+            >>> testdb.drop_database(verbose=True)
+            To drop the database "testdb" from postgres:***@localhost:5432
+            ? [No]|Yes: yes
+            Dropping "testdb" ... Done.
         """
 
-        schemas, schemas_msg = self.msg_for_multi_schemas(schema_names)
+        schemas, print_plural, print_schema = self._msg_for_multi_items(schema_names, desc='schema')
 
         if len(schemas) == 1:
-            cfm_msg_ = "To drop the {} from {}\n?"
+            cfm_msg = "To drop the {} \"{}\" from {}\n?".format(print_plural, print_schema, self.address)
         else:
-            cfm_msg_ = "To drop the following {}\n from {}\n?"
+            cfm_msg = "To drop the following {} from {}: {}\n?".format(
+                print_plural, self.address, print_schema)
 
-        if confirmed(cfm_msg_.format(schemas_msg, self.address), confirmation_required):
+        if confirmed(cfm_msg, confirmation_required=confirmation_required):
 
             if verbose:
                 if len(schemas) == 1:
                     if confirmation_required:
-                        print("Dropping {}".format(schemas_msg.split(" ")[1]), end=" ... ")
+                        log_msg = "Dropping {}".format(print_schema)
                     else:
-                        print("Dropping the {} from {}".format(schemas_msg, self.address), end=" ... ")
-                else:
+                        log_msg = "Dropping the {}: ".format(print_plural, print_schema)
+                    print(log_msg, end=" ... ")
+                else:  # len(schemas) > 1
                     if confirmation_required:
                         print("Dropping ... ")
                     else:
-                        print("Dropping the following schemas from {}:".format(self.address))
+                        print("Dropping the following {} from {}:".format(print_plural, self.address))
 
             for schema in schemas:
                 if not self.schema_exists(schema):
                     # `schema` does not exist
-                    if len(schemas) == 1:
-                        print("Such a schema does not exist.") if verbose else ""
-                    else:
-                        print("\t\"{}\" does not exist.".format(schema)) if verbose else ""
+                    if verbose:
+                        if len(schemas) == 1:
+                            print("The schema \"{}\" does not exist.".format(schemas[0]))
+                        else:
+                            print("\t\"{}\" (does not exist.)".format(schema))
+
                 else:
-                    if len(schemas) > 1:
-                        print("\t\"{}\"".format(schema), end=" ... ") if verbose else ""
+                    if len(schemas) > 1 and verbose:
+                        print("\t\"{}\"".format(schema), end=" ... ")
+
                     try:
                         # schema_ = ('%s, ' * (len(schemas) - 1) + '%s') % tuple(schemas)
                         self.engine.execute('DROP SCHEMA "{}" CASCADE;'.format(schema))
-                        print("Done.") if verbose else ""
+
+                        if verbose:
+                            print("Done.")
+
                     except Exception as e:
                         print("Failed. {}".format(e))
 
@@ -748,6 +781,12 @@ class PostgreSQL:
             >>> testdb.table_exists(table_name='England', schema_name='points')
             >>> # (if 'points.England' does not exist)
             False
+
+            >>> # Delete the database "testdb"
+            >>> testdb.drop_database(verbose=True)
+            To drop the database "testdb" from postgres:***@localhost:5432
+            ? [No]|Yes: yes
+            Dropping "testdb" ... Done.
         """
 
         res = self.engine.execute(
@@ -769,7 +808,7 @@ class PostgreSQL:
         :type schema_name: str
         :param verbose: whether to print relevant information in console as the function runs, 
             defaults to ``False``
-        :type verbose: bool
+        :type verbose: bool or int
 
         .. _postgresql-create_table-example:
 
@@ -844,12 +883,19 @@ class PostgreSQL:
             To drop the table "public"."test_table" from postgres:***@localhost:5432/testdb
             ? [No]|Yes: yes
             Dropping "public"."test_table" ... Done.
+
+            >>> # Delete the database "testdb"
+            >>> testdb.drop_database(verbose=True)
+            To drop the database "testdb" from postgres:***@localhost:5432
+            ? [No]|Yes: yes
+            Dropping "testdb" ... Done.
         """
 
         table_name_ = '"{schema}"."{table}"'.format(schema=schema_name, table=table_name)
 
         if self.table_exists(table_name=table_name, schema_name=schema_name):
-            print("The table {} already exists.".format(table_name_)) if verbose else ""
+            if verbose:
+                print("The table {} already exists.".format(table_name_))
 
         else:
             if not self.schema_exists(schema_name):
@@ -861,7 +907,8 @@ class PostgreSQL:
 
                 self.engine.execute('CREATE TABLE {} ({});'.format(table_name_, column_specs))
 
-                print("Done.") if verbose else ""
+                if verbose:
+                    print("Done.")
 
             except Exception as e:
                 print("Failed. {}".format(e))
@@ -909,7 +956,7 @@ class PostgreSQL:
         :type confirmation_required: bool
         :param verbose: whether to print relevant information in console as the function runs, 
             defaults to ``False``
-        :type verbose: bool
+        :type verbose: bool or int
 
         See the example for the method :py:meth:`.create_table()<pyhelpers.sql.PostgreSQL.create_table>`.
         """
@@ -933,7 +980,10 @@ class PostgreSQL:
 
                 try:
                     self.engine.execute('DROP TABLE "{}"."{}" CASCADE;'.format(schema_name, table_name))
-                    print("Done.") if verbose else ""
+
+                    if verbose:
+                        print("Done.")
+
                 except Exception as e:
                     print("Failed. {}".format(e))
 
@@ -945,7 +995,7 @@ class PostgreSQL:
         :type schema_name: str
         :param verbose: whether to print relevant information in console as the function runs,
             defaults to ``False``
-        :type verbose: bool
+        :type verbose: bool or int
         :return: a list of table names
         :rtype: list or None
 
@@ -1011,7 +1061,7 @@ class PostgreSQL:
         :type confirmation_required: bool
         :param verbose: whether to print relevant information in console as the function runs,
             defaults to ``False``
-        :type verbose: bool
+        :type verbose: bool or int
 
         **Examples**::
 
@@ -1041,6 +1091,7 @@ class PostgreSQL:
             >>> print(lst_tbl_names)
             ['test_table']
 
+            >>> # Delete the database "testdb"
             >>> testdb.drop_database(verbose=True)
             To drop the database "testdb" from postgres:***@localhost:5432
             ? [No]|Yes: yes
@@ -1068,7 +1119,8 @@ class PostgreSQL:
                 self.engine.execute(
                     'ALTER TABLE {} SET SCHEMA "{}";'.format(table_name_, new_schema_name))
 
-                print("Done.") if verbose else ""
+                if verbose:
+                    print("Done.")
 
             except Exception as e:
                 print("Failed. {}".format(e))
@@ -1140,7 +1192,7 @@ class PostgreSQL:
             * callable (e.g. ``PostgreSQL.psql_insert_copy``)
               with signature ``(pd_table, conn, keys, data_iter)``.
 
-        :type method: str or None or types.FunctionType
+        :type method: str or None or typing.Callable
         :param index: whether to dump the index as a column
         :type index: bool
         :param confirmation_required: whether to prompt a message for confirmation to proceed,
@@ -1148,7 +1200,7 @@ class PostgreSQL:
         :type confirmation_required: bool
         :param verbose: whether to print relevant information in console as the function runs, 
             defaults to ``False``
-        :type verbose: bool
+        :type verbose: bool or int
         :param kwargs: optional parameters of `pandas.DataFrame.to_sql`_
 
         .. _`pandas.DataFrame.to_sql`:
@@ -1160,10 +1212,10 @@ class PostgreSQL:
 
         table_name_ = '"{}"."{}"'.format(schema_name, table_name)
 
-        if confirmed("To import the data into table {} at {}\n?".format(table_name_, self.address),
+        if confirmed("To import data into {} at {}\n?".format(table_name_, self.address),
                      confirmation_required=confirmation_required):
 
-            inspector = sqlalchemy.engine.reflection.Inspector.from_engine(self.engine)
+            inspector = sqlalchemy.inspect(self.engine)
             if schema_name not in inspector.get_schema_names():
                 self.create_schema(schema_name, verbose=verbose)
             # if not data.empty:
@@ -1171,23 +1223,20 @@ class PostgreSQL:
 
             if self.table_exists(table_name, schema_name):
                 if if_exists == 'replace' and verbose:
-                    print("The table {} already exists and is replaced ... ".format(table_name_))
+                    print("The table {} already exists and is replaced.".format(table_name_))
 
-                if force_replace:
-                    print("The existing table is forced to be dropped ... ") if verbose else ""
+                if force_replace and verbose:
+                    print("The existing table is forced to be dropped", end=" ... ")
                     self.drop_table(table_name, schema_name,
                                     confirmation_required=confirmation_required, verbose=verbose)
+                    print("Done.")
 
-            # try:
-            #     if verbose:
-            #         if confirmation_required:
-            #             log_msg = "Importing data into {}".format(table_name_)
-            #             log_end_msg = " ... "
-            #         else:
-            #             log_msg = "Importing the data into table {} ... " \
-            #                       "\n\tat {}".format(table_name_, self.address)
-            #             log_end_msg = " ... \n"
-            #         print(log_msg, end=log_end_msg)
+            if verbose == 2:
+                if confirmation_required:
+                    log_msg = "Importing the data into the table {}".format(table_name_)
+                else:
+                    log_msg = "Importing data into the table {} at {}".format(table_name_, self.address)
+                print(log_msg, end=" ... ")
 
             if isinstance(data, (pandas.io.parsers.TextFileReader, list, tuple)):
                 for chunk in data:
@@ -1202,10 +1251,7 @@ class PostgreSQL:
                             **kwargs)
                 gc.collect()
 
-            #     print("Done.") if verbose else ""
-            #
-            # except Exception as e:
-            #     print("Failed. {}".format(e))
+            print("Done.") if verbose == 2 else ""
 
     def read_table(self, table_name, schema_name='public', condition=None, chunk_size=None,
                    sorted_by=None, **kwargs):
@@ -1227,7 +1273,6 @@ class PostgreSQL:
             defaults to ``None``
         :type sorted_by: str or None
         :param kwargs: optional parameters of `pandas.read_sql`_
-
         :return: data frame from the specified table
         :rtype: pandas.DataFrame
 
@@ -1321,58 +1366,65 @@ class PostgreSQL:
             ...             (406689, 286822),
             ...             (383819, 398052),
             ...             (582044, 152953)]
-            >>> col_name = ['Easting', 'Northing']
-            >>> dat = pandas.DataFrame(xy_array, columns=col_name)
+            >>> idx_labels = ['London', 'Birmingham', 'Manchester', 'Leeds']
+            >>> col_names = ['Easting', 'Northing']
+            >>> dat = pandas.DataFrame(xy_array, index=idx_labels, columns=col_names)
 
             >>> print(dat)
-               Easting  Northing
-            0   530034    180381
-            1   406689    286822
-            2   383819    398052
-            3   582044    152953
+                        Easting  Northing
+            London       530034    180381
+            Birmingham   406689    286822
+            Manchester   383819    398052
+            Leeds        582044    152953
 
             >>> table = 'England'
             >>> schema = 'points'
 
-            >>> testdb.import_data(dat, table, schema, if_exists='replace', chunk_size=None,
-            ...                    force_replace=False, col_type=None, verbose=True)
-            To import the data into table "points"."England" at postgres:***@localhost:5432/testdb
+            >>> testdb.import_data(dat, table, schema, if_exists='replace', index=True,
+            ...                    chunk_size=None, force_replace=False, col_type=None, verbose=2)
+            To import data into "points"."England" at postgres:***@localhost:5432/testdb
             ? [No]|Yes: yes
             Creating a schema: "points" ... Done.
-            Importing data into "points"."England" ... Done.
+            Importing the data into the table "points"."England" ... Done.
 
             >>> res = testdb.table_exists(table, schema)
             >>> print("The table \"{}\".\"{}\" exists? {}.".format(schema, table, res))
             The table "points"."England" exists? True.
 
-            >>> dat_retrieval = testdb.read_table(table, schema)
+            >>> dat_retrieval = testdb.read_table(table, schema, index_col='index')
+            >>> dat_retrieval.index.name = None
             >>> print(dat_retrieval)
-               Easting  Northing
-            0   530034    180381
-            1   406689    286822
-            2   383819    398052
-            3   582044    152953
+                        Easting  Northing
+            London       530034    180381
+            Birmingham   406689    286822
+            Manchester   383819    398052
+            Leeds        582044    152953
 
             >>> # Alternatively
-            >>> sql_query_ = 'SELECT * FROM "{}"."{}"'.format(schema, table)
-            >>> dat_retrieval_ = testdb.read_sql_query(sql_query_)
-            >>> print(dat_retrieval_)
-               Easting  Northing
-            0   530034    180381
-            1   406689    286822
-            2   383819    398052
-            3   582044    152953
+            >>> sql_qry = 'SELECT * FROM "{}"."{}"'.format(schema, table)
 
+            >>> dat_retrieval_alt = testdb.read_sql_query(sql_qry, index_col='index')
+            >>> dat_retrieval_alt.index.name = None
+            >>> print(dat_retrieval_alt)
+                        Easting  Northing
+            London       530034    180381
+            Birmingham   406689    286822
+            Manchester   383819    398052
+            Leeds        582044    152953
+
+            >>> # Delete the table "England"
             >>> testdb.drop_table(table_name=table, schema_name=schema, verbose=True)
             To drop the table "points"."England" from postgres:***@localhost:5432/testdb
             ? [No]|Yes: yes
             Dropping "points"."England" ... Done.
 
+            >>> # Delete the schema "points"
             >>> testdb.drop_schema(schema, verbose=True)
             To drop the schema "points" from postgres:***@localhost:5432/testdb
             ? [No]|Yes: yes
             Dropping "points" ... Done.
 
+            >>> # Delete the database "testdb"
             >>> testdb.drop_database(verbose=True)
             To drop the database "testdb" from postgres:***@localhost:5432
             ? [No]|Yes: yes
@@ -1385,12 +1437,12 @@ class PostgreSQL:
 
             import datetime
 
-            sql_query_ = 'SELECT * FROM "table_name" '
-                         'WHERE "timestamp_column_name" BETWEEN %(ts_start)s AND %(ts_end)s'
+            sql_qry = 'SELECT * FROM "table_name" '
+                      'WHERE "timestamp_column_name" BETWEEN %(ts_start)s AND %(ts_end)s'
 
             params = {'ds_start': datetime.datetime.today(), 'ds_end': datetime.datetime.today()}
 
-            data_frame = pd_.read_sql(sql_query_, testdb.engine, params=params)
+            data_frame = pandas.read_sql(sql_qry, testdb.engine, params=params)
         """
 
         methods = ('tempfile', 'stringio', 'spooled')
